==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ro" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Creare foaie de calcul</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Creaţi o nouă foaie de calcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Aliniaţi partea de jos</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Aliniere în jos a conţinutului celulelor selectate</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Aliniere în centru</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Aliniere în centru a conținutului celulelor selectate</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Aliniere la stânga</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Aliniere la stânga a conținutului celulelor selectate</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Aliniere la dreapta</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Aliniere la dreapta a conținutului celulelor selectate</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Aliniere sus</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Aliniere în sus a conţinutului celulelor selectate</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Aliniere verticală centrată</translation>
    </message>
    <message>
      <source>Center-align contents vertically of selected cells</source>
      <translation>Aliniere verticală centrată a conținutului celulelor selectate</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Exportă foaie de calcul</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Exportă foaie de calcul ca fișier CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importă foaie de calcul</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Importă fișier CSV în foaia de calcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Îmbinare celule</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>Îmbinarea celulelor selectate din foaia de calcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation type="unfinished">Set alias</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation type="unfinished">Set alias for selected cell</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Scindare celule</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>Scindaţi celulele îmbinate anterior în foaia de calcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Text aldin</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>Setează text aldin în celulele selectate</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Text cursiv</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>Setează text cursiv în celulele selectate</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Sublinierea textului</translation>
    </message>
    <message>
      <source>Set underline text in selected cells</source>
      <translation>Setează text subliniat în celulele selectate</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom</source>
      <translation>Personalizat</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Proprietăţile celulei</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp; Culoare</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Text</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Fundal</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>Aliniere</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Stanga</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Centru</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Dreapta</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation type="unfinished">Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Partea de sus</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Partea de jos</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp; Stil</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Aldin</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Cursiv</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Subliniat</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>Unitate de afișare</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Unitate de şir</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>Alias</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Alias pentru această celulă</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Tot (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Importă fişier</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Exportă fişier</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>Conținutul celulelor</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Arată foaie de calcul</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation type="unfinished">Set cell(s) foreground color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) foreground color</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation type="unfinished">Set cell(s) background color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) background color</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Negru</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Alb</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Roșu</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Roșu închis</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Verde</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Verde închis</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Albastru</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Albastru închis</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Turcoaz</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Turcoaz închis</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Magenta</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>magenta închis</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Galben</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Galben închis</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Gri</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Gri închis</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Gri deschis</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>Personalizat</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Formular</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>&amp;Conţinutul</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Nedenumit</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Inserare rânduri</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Elimina rânduri</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Inserare coloane</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Eliminați coloane</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Proprietăți...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ro" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Creare foaie de calcul</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Creaţi o nouă foaie de calcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Aliniaţi partea de jos</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Aliniere în jos a conţinutului celulelor selectate</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Aliniere în centru</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Aliniere în centru a conținutului celulelor selectate</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Aliniere la stânga</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Aliniere la stânga a conținutului celulelor selectate</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Aliniere la dreapta</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Aliniere la dreapta a conținutului celulelor selectate</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Aliniere sus</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Aliniere în sus a conţinutului celulelor selectate</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Aliniere verticală centrată</translation>
    </message>
    <message>
      <source>Center-align contents vertically of selected cells</source>
      <translation>Aliniere verticală centrată a conținutului celulelor selectate</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Exportă foaie de calcul</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Exportă foaie de calcul ca fișier CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importă foaie de calcul</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Importă fișier CSV în foaia de calcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Îmbinare celule</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>Îmbinarea celulelor selectate din foaia de calcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Definiți alias</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Definiți alias pentru celula selectată</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Scindare celule</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>Scindaţi celulele îmbinate anterior în foaia de calcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Text aldin</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>Setează text aldin în celulele selectate</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Text cursiv</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>Setează text cursiv în celulele selectate</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Sublinierea textului</translation>
    </message>
    <message>
      <source>Set underline text in selected cells</source>
      <translation>Setează text subliniat în celulele selectate</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom</source>
      <translation>Personalizat</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Proprietăţile celulei</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp; Culoare</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Text</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Fundal</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>Aliniere</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Stanga</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Centru</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Dreapta</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation type="unfinished">Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Partea de sus</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Partea de jos</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp; Stil</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Aldin</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Cursiv</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Subliniat</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>Unitate de afișare</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Unitate de şir</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>Alias</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Alias pentru această celulă</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Tot (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Importă fişier</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Exportă fişier</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>Conținutul celulelor</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Arată foaie de calcul</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Definiți culoarea de prim planul celulei(lor)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Definiți culoarea prim planului celulelor foii de calcul</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Setează culoarea de fundal a celulei(lor)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Définiți culoarea de fundal a celulei(lor) foii de calcul</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Negru</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Alb</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Roșu</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Roșu închis</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Verde</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Verde închis</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Albastru</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Albastru închis</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Turcoaz</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Turcoaz închis</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Magenta</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>magenta închis</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Galben</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Galben închis</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Gri</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Gri închis</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Gri deschis</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>Personalizat</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Formular</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>&amp;Conţinutul</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Nedenumit</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Inserare rânduri</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Elimina rânduri</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Inserare coloane</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Eliminați coloane</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Proprietăți...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Foaie de calcul</translation>
    </message>
  </context>
</TS>
